@@ -6,5 +6,6 @@ from .email import Email
 from .customerio import CustomerIO
 from .create_group_whatsapp import CreateGroupWhatsapp
 from .list_group_whatsapp import ListGroupWhatsapp
+from .whatsapp_template_message_sender import WhatsappTemplateMessageSender
 
-__all__ = ['AbstractChannel', 'ProjectPushNotification', 'UserPushNotification', 'Email', 'CustomerIO', 'CreateGroupWhatsapp', 'ListGroupWhatsapp']
+__all__ = ['AbstractChannel', 'ProjectPushNotification', 'UserPushNotification', 'Email', 'CustomerIO', 'CreateGroupWhatsapp', 'ListGroupWhatsapp', 'WhatsappTemplateMessageSender']
